==> auth-2.4.0717-sources.jar: com/zing/zalo/zalosdk/oauth/ZaloSDK.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import com.zing.zalo.devicetrackingsdk.BaseAppInfoStorage;
import com.zing.zalo.devicetrackingsdk.DeviceTracking;
import com.zing.zalo.devicetrackingsdk.DeviceTracking.GetInfoListener;
import com.zing.zalo.zalosdk.auth.internal.a;
import com.zing.zalo.zalosdk.core.SettingsManager;
import com.zing.zalo.zalosdk.core.exception.InitializedException;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import com.zing.zalo.zalosdk.payment.direct.Utils;
import java.lang.ref.WeakReference;

public class ZaloSDK extends ZaloOAuth {
    public static ZaloSDK Instance = new ZaloSDK();
    private boolean a = false;
    private Authenticator b;
    private LocalizedString c = new LocalizedString();
    private OauthStorage d;
    private a e;

    ZaloSDK() {
    }

    protected synchronized void initialize(Application app) {
        if (!this.a) {
            final Context context = app.getApplicationContext();
            this.d = new OauthStorage(context);
            this.b = new Authenticator(context, this.d, this.c);
            this.a = true;
            this.e = new a(this.d);
            DeviceTracking.getInstance().initDeviceTracking(context, new BaseAppInfoStorage(context), String.valueOf(getAppID()));
            DeviceTracking.getInstance().getDeviceId(new GetInfoListener(this) {
                final /* synthetic */ ZaloSDK b;

                public final void onGetDeviceIdComplete(String deviceId) {
                    SettingsManager.getInstance().init(context, deviceId);
                }
            });
        }
    }

    public Authenticator getAuthenticator() {
        return this.b;
    }

    public LocalizedString getLocalizedString() {
        return this.c;
    }

    public void setLocalizedString(LocalizedString localizedString) {
        this.c = localizedString;
    }

    public void authenticate(Activity activity, OAuthCompleteListener listener) {
        authenticate(activity, LoginVia.APP, listener);
    }

    public void authenticate(Activity activity, LoginVia loginVia, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.authenticate(activity, loginVia, false, listener);
    }

    protected void authenticateZaloPlugin(Activity activity, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.authenticate(activity, LoginVia.APP_OR_WEB, true, listener);
    }

    public void setOauthCompletedListener(OAuthCompleteListener listener) {
        checkInitialize();
        this.b.setOAuthCompleteListener(listener);
    }

    public void unauthenticate() {
        checkInitialize();
        this.b.unauthenticate();
    }

    public boolean isAuthenticate(ValidateOAuthCodeCallback callback) {
        return isAuthenticate(this.d.getOAuthCode(), callback);
    }

    protected boolean isAuthenticate(String oauthCode, ValidateOAuthCodeCallback callback) {
        checkInitialize();
        return this.b.isAuthenticate(oauthCode, callback);
    }

    public final boolean onActivityResult(Activity activity, int requestCode, int resultCode, Intent data) {
        return this.b.onActivityResult(activity, requestCode, resultCode, data);
    }

    public void requestPermissions(Activity activity, Enum<Permissions> permission, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.requestPermissions(activity, permission, listener);
    }

    public String getOAuthCode() {
        checkInitialize();
        return this.d.getOAuthCode();
    }

    public String getLastestLoginChannel() {
        return this.d.getLastestLoginChannel();
    }

    public long getAppID() {
        return ZaloSDKApplication.appID;
    }

    public long getZaloId() {
        checkInitialize();
        return this.d.getZaloId();
    }

    public String getZaloDisplayname() {
        checkInitialize();
        return this.d.getZaloDisplayName();
    }

    public String getSocialId() {
        checkInitialize();
        return this.d.getSocialId();
    }

    public void getProfile(Context ctx, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        new HttpClientRequest(Type.GET, aVar.a).addParams("fields", a.a(fields));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{r1});
    }

    public void getFriendListUsedApp(Context ctx, int position, int count, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.GET, aVar.a + "/friends");
        httpClientRequest.addParams("fields", a.a(fields));
        httpClientRequest.addParams("offset", String.valueOf(position));
        httpClientRequest.addParams("limit", String.valueOf(count));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void getFriendListInvitable(Context ctx, int position, int count, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.GET, aVar.a + "/invitable_friends");
        httpClientRequest.addParams("fields", a.a(fields));
        httpClientRequest.addParams("offset", String.valueOf(position));
        httpClientRequest.addParams("limit", String.valueOf(count));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void inviteFriendUseApp(Context ctx, String[] friendId, String message, ZaloOpenAPICallback callback) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, "https://graph.zaloapp.com/v2.0/apprequests");
        httpClientRequest.addParams("to", a.a(friendId));
        httpClientRequest.addParams("message", message);
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void checkInitialize() {
        if (!this.a) {
            throw new InitializedException("Missing call declare com.zing.zalo.zalosdk.oauth.ZaloSDKApplication in Application or call wrap init");
        }
    }

    public String getVersion() {
        return "2.4.0717";
    }

    public void setLogLevel(int logLevel) {
        Log.setLogLevel(logLevel);
    }

    public String getDeviceId() {
        return DeviceTracking.getInstance().getDeviceId();
    }

    public void getDeviceId(GetInfoListener getDeviceIdListener) {
        DeviceTracking.getInstance().getDeviceId(getDeviceIdListener);
    }

    public String getGuestDeviceId() {
        checkInitialize();
        return this.d.getGuestDeviceId();
    }

    public int getIsGuestCertificated() {
        checkInitialize();
        return this.d.getIsGuestCertificated();
    }

    public String getSDKId() {
        return DeviceTracking.getInstance().getSDKId();
    }

    public String getPrivateKey() {
        return DeviceTracking.getInstance().getPrivateKey();
    }

    public DeviceTracking getBaseAppInfo() {
        return DeviceTracking.getInstance();
    }

    public OauthStorage getOauthStorage() {
        return this.d;
    }

    public void setLanguageSDK(Context context, String language) {
        Utils.setLanguage(context, language);
    }

    public void registerZalo(Activity activity, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.registerZalo(activity, listener);
    }

    public void setApplicationID(long appID) {
        ZaloSDKApplication.appID = appID;
    }
}

==> auth-2.4.0823-sources.jar: com/zing/zalo/zalosdk/oauth/ZaloSDK.java <==
package com.zing.zalo.zalosdk.oauth;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import com.zing.zalo.devicetrackingsdk.DeviceTracking;
import com.zing.zalo.devicetrackingsdk.DeviceTracking.GetInfoListener;
import com.zing.zalo.zalosdk.auth.internal.a;
import com.zing.zalo.zalosdk.core.exception.InitializedException;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import com.zing.zalo.zalosdk.core.servicemap.ServiceMapManager;
import com.zing.zalo.zalosdk.payment.direct.Utils;
import java.lang.ref.WeakReference;

public class ZaloSDK {
    public static ZaloSDK Instance = new ZaloSDK();
    private boolean a = false;
    private Authenticator b;
    private LocalizedString c = new LocalizedString();
    private OauthStorage d;
    private a e;

    ZaloSDK() {
    }

    protected synchronized void initialize(Application app) {
        if (!this.a) {
            Context context = app.getApplicationContext();
            this.d = new OauthStorage(context);
            this.b = new Authenticator(context, this.d, this.c);
            this.a = true;
            this.e = new a(this.d);
        }
    }

    public Authenticator getAuthenticator() {
        return this.b;
    }

    public LocalizedString getLocalizedString() {
        return this.c;
    }

    public void setLocalizedString(LocalizedString localizedString) {
        this.c = localizedString;
    }

    public void authenticate(Activity activity, OAuthCompleteListener listener) {
        authenticate(activity, LoginVia.APP, listener);
    }

    public void authenticate(Activity activity, LoginVia loginVia, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.authenticate(activity, loginVia, false, listener);
    }

    protected void authenticateZaloPlugin(Activity activity, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.authenticate(activity, LoginVia.APP_OR_WEB, true, listener);
    }

    public void setOauthCompletedListener(OAuthCompleteListener listener) {
        checkInitialize();
        this.b.setOAuthCompleteListener(listener);
    }

    public void unauthenticate() {
        checkInitialize();
        this.b.unauthenticate();
    }

    public boolean isAuthenticate(ValidateOAuthCodeCallback callback) {
        return isAuthenticate(this.d.getOAuthCode(), callback);
    }

    protected boolean isAuthenticate(String oauthCode, ValidateOAuthCodeCallback callback) {
        checkInitialize();
        return this.b.isAuthenticate(oauthCode, callback);
    }

    public final boolean onActivityResult(Activity activity, int requestCode, int resultCode, Intent data) {
        return this.b.onActivityResult(activity, requestCode, resultCode, data);
    }

    public void requestPermissions(Activity activity, Enum<Permissions> permission, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.requestPermissions(activity, permission, listener);
    }

    public String getOAuthCode() {
        checkInitialize();
        return this.d.getOAuthCode();
    }

    public String getLastestLoginChannel() {
        return this.d.getLastestLoginChannel();
    }

    public long getAppID() {
        try {
            return Long.parseLong(ZaloSDKApplication.appID);
        } catch (Exception e) {
            return 0;
        }
    }

    public long getZaloId() {
        checkInitialize();
        return this.d.getZaloId();
    }

    public String getZaloDisplayname() {
        checkInitialize();
        return this.d.getZaloDisplayName();
    }

    public String getSocialId() {
        checkInitialize();
        return this.d.getSocialId();
    }

    public void getProfile(Context ctx, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        new HttpClientRequest(Type.GET, ServiceMapManager.getInstance().urlFor("graph_http_s", "/v2.0/me")).addParams("fields", a.a(fields));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{r1});
    }

    public void getFriendListUsedApp(Context ctx, int position, int count, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.GET, ServiceMapManager.getInstance().urlFor("graph_http_s", "/v2.0/me/friends"));
        httpClientRequest.addParams("fields", a.a(fields));
        httpClientRequest.addParams("offset", String.valueOf(position));
        httpClientRequest.addParams("limit", String.valueOf(count));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void getFriendListInvitable(Context ctx, int position, int count, ZaloOpenAPICallback callback, String[] fields) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.GET, ServiceMapManager.getInstance().urlFor("graph_http_s", "/v2.0/me/invitable_friends"));
        httpClientRequest.addParams("fields", a.a(fields));
        httpClientRequest.addParams("offset", String.valueOf(position));
        httpClientRequest.addParams("limit", String.valueOf(count));
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void inviteFriendUseApp(Context ctx, String[] friendId, String message, ZaloOpenAPICallback callback) {
        checkInitialize();
        a aVar = this.e;
        HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, ServiceMapManager.getInstance().urlFor("graph_http_s", "/v2.0/apprequests"));
        httpClientRequest.addParams("to", a.a(friendId));
        httpClientRequest.addParams("message", message);
        new a.a(aVar, ctx, new WeakReference(callback)).execute(new HttpClientRequest[]{httpClientRequest});
    }

    public void checkInitialize() {
        if (!this.a) {
            throw new InitializedException("Missing call declare com.zing.zalo.zalosdk.oauth.ZaloSDKApplication in Application or call wrap init");
        }
    }

    public String getVersion() {
        return "2.4.0823";
    }

    public void setLogLevel(int logLevel) {
        Log.setLogLevel(logLevel);
    }

    public String getDeviceId() {
        return DeviceTracking.getInstance().getDeviceId();
    }

    public void getDeviceId(GetInfoListener getDeviceIdListener) {
        DeviceTracking.getInstance().getDeviceId(getDeviceIdListener);
    }

    public String getGuestDeviceId() {
        checkInitialize();
        return this.d.getGuestDeviceId();
    }

    public int getIsGuestCertificated() {
        checkInitialize();
        return this.d.getIsGuestCertificated();
    }

    public String getSDKId() {
        return DeviceTracking.getInstance().getSDKId();
    }

    public String getPrivateKey() {
        return DeviceTracking.getInstance().getPrivateKey();
    }

    public DeviceTracking getBaseAppInfo() {
        return DeviceTracking.getInstance();
    }

    public OauthStorage getOauthStorage() {
        return this.d;
    }

    public void setLanguageSDK(Context context, String language) {
        Utils.setLanguage(context, language);
    }

    public void registerZalo(Activity activity, OAuthCompleteListener listener) {
        checkInitialize();
        this.b.registerZalo(activity, listener);
    }

    public void setApplicationID(long appID) {
        ZaloSDKApplication.appID = String.valueOf(appID);
    }

    public void getZaloLoginStatus(GetZaloLoginStatus callback) {
        checkInitialize();
        this.b.getZaloLoginStatus(callback);
    }
}
